=======
History
=======

1.0.13 (2020-01-14)
-------------------

* Added the ability to change the map line colour through a separate variable
* Previous demonstration data replaced with SITL generated data

1.0.12 (2020-01-13)
-------------------

* Map formatting improved
* Documentation updated with images and examples


1.0.11 (2020-01-09)
-------------------

* Improved code formatting
* Added improved map backplotting for greater speed

1.0.10 (2020-01-07)
-------------------

* Removed warnings in the jupyter notebook
* Improved the map backplotting function
* Renamed graph_function to graph_plotter

1.0.9 (2020-01-06)
------------------

* Repaired map backplotting functions
* Added scale factor to map

1.0.8 (2019-12-12)
------------------

* Upgraded from .xls to .xlsx

1.0.7 (2019-12-11)
------------------

* Figure sizes changed

1.0.6 (2019-12-11)
------------------

* Fixed minor issues
* Added better map package installation instructions

1.0.5 (2019-12-10)
------------------

* Added data compression for faster notebook running

1.0.4 (2019-12-05)
------------------

* Added backplotted map for latitude and longitude data

1.0.3 (2019-11-28)
------------------

* Compatibility extended to Python 3.5 and 3.8
* Improved the default template and plotting functions

1.0.2 (2019-11-26)
------------------

* Compatibility for multiple operating systems improved

1.0.1 (2019-11-26)
------------------

* Metar module issue fixed

1.0.0 (2019-11-25)
------------------

* Autoflpy v 1.0.0 released

0.2.6 (2019-11-25)
------------------

* Updated Default Template with GPS and autopilot data
* Imporved unit testing

0.2.5 (2019-11-14)
------------------

* Checklist issues resolved
* Unittests expanded

0.2.4 (2019-11-14)
------------------

* Documentation updated

0.2.3 (2019-11-12)
------------------

* Changed autoflpy.py to log_analysis.py


0.2.2 (2019-11-12)
------------------

* Default storage directory bug fixed

0.2.1 (2019-11-12)
------------------

* Generated the input file into the generated folder structure
* Added example data for first time running

0.2.0 (2019-11-08)
------------------

* Fixed path issues in template

0.1.4 (2019-11-08)
------------------

* Fixed more directory issues

0.1.3 (2019-11-08)
------------------

* Fixed directory issues

0.1.2 (2019-11-08)
------------------

* Reformatted directory and added default user files.

0.1.1 (2019-11-07)
------------------

* Updates and added code. Reformatted directory.

0.1.0 (2019-10-29)
------------------

* First release on PyPI.
